@@ -76,13 +76,44 @@ class Storage(object):
         """
         return self.store(data)
 
-    def get_usage(self, start_date=None, end_date=None, limit=None):
+    def _get_usage(self, start_date=None, end_date=None, limit=500, page=1):
         """
-        Returns simple usage information by criteria in a standard list form.
+        Implements simple usage information by criteria in a standard list form
 
         :Parameters:
            - `start_date`: datetime.datetime representation of starting date
            - `end_date`: datetime.datetime representation of ending date
            - `limit`: The max amount of results to return
+           - `page`: Result page number limited by `limit` number in a page
         """
         raise NotImplementedError('get_usage must be implemented.')
+
+    def get_usage(self, start_date=None, end_date=None, limit=500, page=1):
+        """
+        Returns simple usage information by criteria in a standard list form.
+
+        .. note::
+           *limit* is the amount if items returned per *page*.
+           If *page* is not incremented you will always receive the
+           first *limit* amount of results.
+
+        .. versionadded:: 1.0.0
+           The *page* parameter.
+
+        :Parameters:
+           - `start_date`: datetime.datetime representation of starting date
+           - `end_date`: datetime.datetime representation of ending date
+           - `limit`: The max amount of results to return
+           - `page`: Result page number limited by `limit` number in a page
+        """
+        raw_data = self._get_usage(start_date, end_date, limit, page)
+        if type(raw_data) != list:
+            raise Exception(
+                'Container returned from _get_usage '
+                'does not conform to the spec.')
+        for item in raw_data:
+            if type(item) != dict:
+                raise Exception(
+                    'An item returned from _get_usage '
+                    'does not conform to the spec.')
+        return raw_data
